@@ -311,7 +311,7 @@ class language_learner:
         self.content_random_order = False
         self.input_text = ''
         self.button_object_list = []
-        self.path_source = os.path.join(current_path, "source")
+
 
         # self.df = pd.read_csv (data_file,sep = '|')
         # self.df_backup = self.df.copy(deep=True)
@@ -845,7 +845,8 @@ class language_learner:
         self.report_path = self.generate_new_folder('L_report')
         self.record_path = self.generate_new_folder('L_record')
         self.source_path = self.generate_new_folder('L_source')
-
+        self.path_source = self.generate_new_folder("source")
+        
         self.initialize_widgets_for_start()
         self.generate_problem_list_from_database()
         self.problem_index = 0
@@ -898,7 +899,9 @@ class language_learner:
         input_text = []
         # os.getcwd()
         path_txt = filedialog.askopenfilename(title = "Select file",filetypes = (("CSV Files","*.csv"),))
-        self.path_csv = path_txt
+        self.path_csv = os.path.dirname(path_txt)
+
+
         try:
             self.df = pd.read_csv (path_txt,sep = '|')
         except:
